Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(60)

Unified Diff: components/history/core/browser/history_service.h

Issue 2949023002: [WIP] Fix history.replaceState() not propagating back favicons (Closed)
Patch Set: Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/history/core/browser/history_service.h
diff --git a/components/history/core/browser/history_service.h b/components/history/core/browser/history_service.h
index b1aedcdf65599ab0482f601fae9c1f5f029d1d52..27bc42be420017090b6cfc9bc762249f4c20771b 100644
--- a/components/history/core/browser/history_service.h
+++ b/components/history/core/browser/history_service.h
@@ -198,8 +198,8 @@ class HistoryService : public syncer::SyncableService, public KeyedService {
// one entry). If there are no redirects, this array may also be empty for
// the convenience of callers.
//
// 'did_replace_entry' is true when the navigation entry for this page has
// replaced the existing entry. A non-user initiated redirect causes such
// replacement.
//
// All "Add Page" functions will update the visited link database.
@@ -211,7 +211,7 @@ class HistoryService : public syncer::SyncableService, public KeyedService {
const RedirectList& redirects,
ui::PageTransition transition,
VisitSource visit_source,
- bool did_replace_entry);
+ base::Optional<GURL> replaced_entry_url);
// For adding pages to history where no tracking information can be done.
void AddPage(const GURL& url, base::Time time, VisitSource visit_source);
@@ -198,8 +198,8 @@ class HistoryService : public syncer::SyncableService, public KeyedService {
// the convenience of callers.
//
- // 'did_replace_entry' is true when the navigation entry for this page has
- // replaced the existing entry. A non-user initiated redirect causes such
+ // 'replaced_entry_url' is non-empty when the navigation entry for this page
+ // has replaced the existing entry. A non-user initiated redirect causes such
// replacement.
//

Powered by Google App Engine
This is Rietveld 408576698